@@ -23,7 +23,7 @@ final class TraversableContainsEqual extends TraversableContains
     protected function matches(mixed $other): bool
     {
         if ($other instanceof SplObjectStorage) {
-            return $other->contains($this->value());
+            return $other->offsetExists($this->value());
         }
 
         foreach ($other as $element) {
